@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: event.c,v 1.271 2004/12/16 16:14:08 f1rmb Exp $
+ * $Id: event.c,v 1.276 2005/07/24 02:40:37 fsck-p Exp $
  *
  * gui initialization and top-level event handling stuff
  *
@@ -43,6 +43,7 @@
 #include <stdlib.h>
 
 #include "common.h"
+#include "oxine/oxine.h"
 
 #define STEP_SIZE 256
 
@@ -167,7 +168,7 @@ static void visual_anim_cb(void *data, xine_cfg_entry_t *cfg) {
     
     if(!has_video && !gGui->visual_anim.running) {
       if(gGui->visual_anim.enabled == 1) {
-	if(gGui->visual_anim.post_output) {
+	if(gGui->visual_anim.post_output_element.post) {
 	  if(post_rewire_audio_post_to_stream(gGui->stream))
 	    gGui->visual_anim.running = 1;
 	}
@@ -394,6 +395,10 @@ void gui_execute_action_id(action_id_t action) {
       gGui->numeric.arg = 0;
     }
 
+    /* check if osd menu like this event */
+    if( oxine_action_event(action & ~ACTID_IS_INPUT_EVENT) )
+      return;
+    
     /* events for advanced input plugins. */
     xine_event.type        = action & ~ACTID_IS_INPUT_EVENT;
     xine_event.data_length = 0;
@@ -646,8 +651,10 @@ void gui_execute_action_id(action_id_t action) {
       int av_offset = (xine_get_param(gGui->stream, XINE_PARAM_AV_OFFSET) - 3600);
 
       gGui->mmk.av_offset = av_offset;
-      if (gGui->playlist.cur < gGui->playlist.num)
-        gGui->playlist.mmk[gGui->playlist.cur]->av_offset = av_offset;
+      if (gGui->playlist.num && gGui->playlist.cur >= 0 && gGui->playlist.mmk &&
+	  gGui->playlist.mmk[gGui->playlist.cur])
+	if (gGui->playlist.cur < gGui->playlist.num)
+	  gGui->playlist.mmk[gGui->playlist.cur]->av_offset = av_offset;
       xine_set_param(gGui->stream, XINE_PARAM_AV_OFFSET, av_offset);
       osd_display_info(_("A/V offset: %s"), pts2str(av_offset));
     }
@@ -658,14 +665,21 @@ void gui_execute_action_id(action_id_t action) {
       int av_offset = (xine_get_param(gGui->stream, XINE_PARAM_AV_OFFSET) + 3600);
       
       gGui->mmk.av_offset = av_offset;
-      if (gGui->playlist.cur < gGui->playlist.num)
-        gGui->playlist.mmk[gGui->playlist.cur]->av_offset = av_offset;
+      if (gGui->playlist.num && gGui->playlist.cur >= 0 && gGui->playlist.mmk &&
+	  gGui->playlist.mmk[gGui->playlist.cur])
+	if (gGui->playlist.cur < gGui->playlist.num)
+	  gGui->playlist.mmk[gGui->playlist.cur]->av_offset = av_offset;
       xine_set_param(gGui->stream, XINE_PARAM_AV_OFFSET, av_offset);
       osd_display_info(_("A/V offset: %s"), pts2str(av_offset));
     }
     break;
 
   case ACTID_AV_SYNC_RESET:
+    gGui->mmk.av_offset = 0;
+    if (gGui->playlist.num && gGui->playlist.cur >= 0 && gGui->playlist.mmk &&
+	gGui->playlist.mmk[gGui->playlist.cur])
+      if (gGui->playlist.cur < gGui->playlist.num)
+	gGui->playlist.mmk[gGui->playlist.cur]->av_offset = 0;
     xine_set_param(gGui->stream, XINE_PARAM_AV_OFFSET, 0);
     osd_display_info(_("A/V Offset: reset."));
     break;
@@ -715,6 +729,14 @@ void gui_execute_action_id(action_id_t action) {
     gui_decrease_audio_volume();
     break;
 
+  case ACTID_APP:
+    gui_app_show(NULL, NULL);
+    break;
+
+  case ACTID_APP_ENABLE:
+    gui_app_enable();
+    break;
+
   case ACTID_pAMP:
     gui_increase_amp_level();
     break;
@@ -851,6 +873,10 @@ void gui_execute_action_id(action_id_t action) {
   case ACTID_OSD_SINFOS:
     osd_stream_infos();
     break;
+  
+  case ACTID_OSD_MENU:
+    oxine_menu();
+    break;
 
   case ACTID_FILESELECTOR:
     gui_file_selector();
@@ -1311,7 +1337,8 @@ void gui_init (int nfiles, char *filenames[], window_attributes_t *window_attrib
   if (xine_config_register_bool (gGui->xine, "gui.xsynchronize", 
 				 0,
 				 _("Synchronized X protocol (debug)"), 
-				 CONFIG_NO_HELP,
+				 _("Do X transactions in synchronous mode. "
+				   "Very slow, use only for debugging!"), 
 				 CONFIG_LEVEL_ADV,
 				 CONFIG_NO_CB,
 				 CONFIG_NO_DATA)) {
@@ -1352,8 +1379,8 @@ void gui_init (int nfiles, char *filenames[], window_attributes_t *window_attrib
   
   gGui->ssaver_timeout =
     xine_config_register_num (gGui->xine, "gui.screensaver_timeout", 10,
-			      _("Screensaver wakeup"),
-			      _("Time between two screensaver fake events, 0 to disable."),
+			      _("Screensaver reset interval (s)"),
+			      _("Time, in seconds, between two faked events to keep a screensaver quiet, 0 to disable."),
 			      CONFIG_LEVEL_ADV,
 			      ssaver_timeout_cb,
 			      CONFIG_NO_DATA);
@@ -1528,6 +1555,8 @@ void gui_init (int nfiles, char *filenames[], window_attributes_t *window_attrib
   gGui->video_screen = DefaultScreen(gGui->video_display);
   XUnlockDisplay (gGui->video_display);
 
+  
+
   /* Some infos */
   if(gGui->verbosity) {
     dump_host_info();
@@ -1801,6 +1830,8 @@ void gui_run(char **session_opts) {
   startup.start        = auto_start;
   startup.session_opts = session_opts;
 
+  oxine_init();
+  
   xitk_run(on_start, (void *)&startup);
 
   /* save playlist */
@@ -1811,13 +1842,6 @@ void gui_run(char **session_opts) {
     mediamark_save_mediamarks(buffer);
   }
 
-  { /* Give focus to the ROOT window, to get C-Tab working */
-    Window rootwindow, wparent;
-    
-    if((rootwindow = xitk_get_desktop_root_window(gGui->video_display, gGui->video_screen, &wparent)) != None)
-      try_to_set_input_focus(rootwindow);
-  }
-
   gGui->running = 0;
   deinit_session();
 
