@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: file_browser.c,v 1.55 2004/07/02 21:41:02 f1rmb Exp $
+ * $Id: file_browser.c,v 1.59 2005/05/29 10:43:40 valtri Exp $
  *
  */
 
@@ -29,7 +29,6 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/keysym.h>
-#include <X11/cursorfont.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <dirent.h>
@@ -83,7 +82,7 @@ typedef struct {
 static filebrowser_filter_t __fb_filters[] = {
   { NULL, "*"                                                                      },
  /* subtitles */
-  { NULL, ".sub .srt .asc .smi .ssa "                                              },
+  { NULL, ".sub .srt .asc .smi .ssa .txt"                                          },
   /* playlists */
   { NULL, ".pls .m3u .sfv .tox .asx .smil .smi .xml .fxd "                         },
   { "*.4xm", ".4xm "                                                               },
@@ -142,8 +141,6 @@ struct filebrowser_s {
 
   xitk_widget_t                  *origin;
 
-  Cursor                          cursor[2];
-
   xitk_widget_t                  *directories_browser;
   xitk_widget_t                  *directories_sort;
   int                             directories_sort_direction;
@@ -237,10 +234,10 @@ static void fb_reactivate(filebrowser_t *fb) {
 
 static void _fb_set_cursor(filebrowser_t *fb, int state) {
   if(fb) {
-    XLockDisplay(gGui->display);
-    XDefineCursor(gGui->display, (xitk_window_get_window(fb->xwin)), fb->cursor[state]);
-    XSync(gGui->display, False);
-    XUnlockDisplay(gGui->display);
+    if(state == WAIT_CURS)
+      xitk_cursors_define_window_cursor(gGui->display, (xitk_window_get_window(fb->xwin)), xitk_cursor_watch);
+    else
+      xitk_cursors_restore_window_cursor(gGui->display, (xitk_window_get_window(fb->xwin)));
   }
 }
 /*
@@ -427,9 +424,17 @@ static int is_file_match_to_filter(filebrowser_t *fb, char *file) {
     char *ending;
 
     if((ending = strrchr(file, '.'))) {
-      char ext[strlen(ending) + 2];
+      char  ext[strlen(ending) + 2];
+      char *p;
       
       sprintf(ext, "%s ", ending);
+
+      p = ext;
+      while(*p && (*p != '\0')) {
+	*p = tolower(*p);
+	p++;
+      }
+	
       if(strstr(__fb_filters[fb->filter_selected].ending, ext))
 	return 1;
       
@@ -903,8 +908,6 @@ static void fb_exit(xitk_widget_t *w, void *data) {
     xitk_list_free((XITK_WIDGET_LIST_LIST(fb->widget_list)));
     
     XLockDisplay(gGui->display);
-    XFreeCursor(gGui->display, fb->cursor[NORMAL_CURS]);
-    XFreeCursor(gGui->display, fb->cursor[WAIT_CURS]);
     XFreeGC(gGui->display, (XITK_WIDGET_LIST_GC(fb->widget_list)));
     XUnlockDisplay(gGui->display);
     
@@ -1000,7 +1003,7 @@ static void fb_delete_file(xitk_widget_t *w, void *data) {
   if((sel = xitk_browser_get_current_selected(fb->files_browser)) >= 0) {
     char buf[256 + XITK_PATH_MAX + XITK_NAME_MAX + 1];
 
-    snprintf(buf, sizeof(buf), _("Do you really want to delete the file: '%s"), fb->current_dir);
+    snprintf(buf, sizeof(buf), _("Do you really want to delete the file: '%s'"), fb->current_dir);
     if(strlen(fb->current_dir) > 1)
       strcat(buf, "/");
     sprintf(buf, "%s%s' ?.", buf, fb->norm_files[sel].name);
@@ -1251,8 +1254,6 @@ filebrowser_t *create_filebrowser(char *window_title, char *filepathname, hidden
   XLockDisplay(gGui->display);
   gc = XCreateGC(gGui->display, 
 		 (xitk_window_get_window(fb->xwin)), None, None);
-  fb->cursor[NORMAL_CURS] = XCreateFontCursor(gGui->display, XC_left_ptr);
-  fb->cursor[WAIT_CURS] = XCreateFontCursor(gGui->display, XC_watch);
   XUnlockDisplay(gGui->display);
 
   fb->widget_list                = xitk_widget_list_new();
