@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: kbindings.h,v 1.55 2004/12/16 16:14:09 f1rmb Exp $
+ * $Id: kbindings.h,v 1.57 2005/07/16 19:05:31 miguelfreitas Exp $
  *
  */
 #ifndef KBINDINGS_H
@@ -142,6 +142,9 @@ typedef enum {
   ACTID_VPP_ENABLE,
   ACTID_HELP_SHOW,
   ACTID_PLAYLIST_STOP,
+  ACTID_OSD_MENU,
+  ACTID_APP,
+  ACTID_APP_ENABLE,
 
   /*
    * The below events map one-to-one with definitions in xine-lib's events.h 
