@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: network.c,v 1.63 2004/05/23 22:31:13 f1rmb Exp $
+ * $Id: network.c,v 1.65 2005/07/16 19:05:32 miguelfreitas Exp $
  *
  * xine network related stuff
  *
@@ -2374,6 +2374,10 @@ static void do_gui(commands_t *cmd, client_info_t *client_info) {
 	gui_vpp_show(NULL, NULL);
 	flushing++;
       }
+      else if(is_arg_contain(client_info, 1, "apost")) {
+	gui_app_show(NULL, NULL);
+	flushing++;
+      }
       else if(is_arg_contain(client_info, 1, "help")) {
 	gui_help_show(NULL, NULL);
 	flushing++;
@@ -2914,14 +2918,22 @@ static void *server_thread(void *data) {
   char            *service;
   struct servent  *serv_ent;
   int              msock;
+  
+  if(gGui->network_port) {
+    int len = (int) log10(gGui->network_port) + 1;
 
-  /*  Search in /etc/services if a xinectl entry exist */
-  if((serv_ent = getservbyname("xinectl", "tcp")) != NULL) {
-    service = (char *) xine_xmalloc(ntohs(serv_ent->s_port));
-    sprintf(service, "%u", ntohs(serv_ent->s_port));
-  }
-  else
-    service = strdup(DEFAULT_XINECTL_PORT);
+    service = (char *) xine_xmalloc(len + 1);
+    sprintf(service, "%u", gGui->network_port);
+  } 
+  else {
+    /*  Search in /etc/services if a xinectl entry exist */
+    if((serv_ent = getservbyname("xinectl", "tcp")) != NULL) {
+      service = (char *) xine_xmalloc(ntohs(serv_ent->s_port));
+      sprintf(service, "%u", ntohs(serv_ent->s_port));
+    }
+    else
+      service = strdup(DEFAULT_XINECTL_PORT);
+  }  
   
   /* Load passwd file */
   /* password file syntax is:
