@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: label.c,v 1.69 2004/06/13 11:44:18 f1rmb Exp $
+ * $Id: label.c,v 1.71 2004/07/23 13:12:40 f1rmb Exp $
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -133,6 +133,8 @@ static void notify_destroy(xitk_widget_t *w) {
     XITK_FREE(private_data->fontname);
     XITK_FREE(private_data->skin_element_name);
 
+    pthread_mutex_unlock(&private_data->paint_mutex);
+    pthread_mutex_unlock(&private_data->change_mutex);
     pthread_mutex_destroy(&private_data->paint_mutex);
     pthread_mutex_destroy(&private_data->change_mutex);
 
@@ -323,7 +325,7 @@ static void label_setup_label(xitk_widget_t *w, char *label_) {
     
     if(label_len > private_data->length) {
       pthread_attr_t       pth_attrs;
-#if ! defined (__OpenBSD__)
+#ifdef _POSIX_THREAD_PRIORITY_SCHEDULING
       struct sched_param   pth_params;
 #endif
       
@@ -331,15 +333,13 @@ static void label_setup_label(xitk_widget_t *w, char *label_) {
       
       pthread_attr_init(&pth_attrs);
 
-      /* this won't work on linux, freebsd 5.0 */
-#if ! defined (__OpenBSD__)
+#ifdef _POSIX_THREAD_PRIORITY_SCHEDULING
       pthread_attr_getschedparam(&pth_attrs, &pth_params);
       pth_params.sched_priority = sched_get_priority_min(SCHED_OTHER);
       pthread_attr_setschedparam(&pth_attrs, &pth_params);
 #endif
       
-      pthread_create(&private_data->thread, &pth_attrs, 
-      		     xitk_label_animation_loop, (void *)private_data);
+      pthread_create(&private_data->thread, &pth_attrs, xitk_label_animation_loop, (void *)private_data);
     }
   }
 
