@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: xitk.c,v 1.132 2004/12/15 21:10:48 f1rmb Exp $
+ * $Id: xitk.c,v 1.137 2005/05/20 22:02:05 fsck-p Exp $
  *
  */
 #define _XITK_C_
@@ -147,8 +147,16 @@ typedef struct {
   
   struct timeval              keypress;
 
+  KeyCode                     ignore_keys[3];
+
   pthread_t                  *tips_thread;
   unsigned long               tips_timeout;
+
+  struct {
+    Window                    window;
+    int                       focus;
+  } parent;
+  
 } __xitk_t;
 
 static __xitk_t    *gXitk;
@@ -458,7 +466,6 @@ static uint32_t xitk_check_wm(Display *display) {
     type |= WM_TYPE_LARSWM;
   }
   else if(((atom = XInternAtom(display, "KWIN_RUNNING", True)) != None) &&
-	  ((atom = XInternAtom(display, "_KDE_NET_USER_TIME", True)) != None) &&
 	  ((atom = XInternAtom(display, "_DT_SM_WINDOW_INFO", True)) != None)) {
     type |= WM_TYPE_KWIN;
   }
@@ -1193,10 +1200,9 @@ void xitk_unregister_event_handler(xitk_register_key_t *key) {
 	MUTUNLOCK();
 	return;
       }
+      FXUNLOCK(fx);
     }
 
-    FXUNLOCK(fx);
-
     fx = (__gfx_t *) xitk_list_next_content(gXitk->gfx);
   }
 
@@ -1265,6 +1271,19 @@ void xitk_xevent_notify(XEvent *event) {
      
   if(!(fx = (__gfx_t *) xitk_list_first_content(gXitk->gfx)))
     return;
+
+  if(event->type == KeyPress || event->type == KeyRelease) {
+
+    /* Filter keys that dont't need to be handled by xine  */
+    /* and could be used by our screen saver reset "ping". */
+    /* So they will not kill tips and menus.               */
+
+    int i;
+
+    for(i = 0; i < sizeof(gXitk->ignore_keys)/sizeof(gXitk->ignore_keys[0]); ++i)
+      if(event->xkey.keycode == gXitk->ignore_keys[i])
+	return;
+  }
   
   FXLOCK(fx);
   
@@ -1448,8 +1467,10 @@ void xitk_xevent_notify(XEvent *event) {
 	    if(w && ((w->type & WIDGET_GROUP_MASK) & WIDGET_GROUP_BROWSER)) {
 	      xitk_widget_t *b = xitk_browser_get_browser(w);
 	      
-	      if(b)
+	      if(b) {
+		handled = 1;
 		xitk_browser_warp_jump(b, kbuf, modifier);
+	      }
 
 	    }
 	  }
@@ -1784,7 +1805,11 @@ void xitk_init(Display *display, XColor black, int verbosity) {
   xitk_x_error           = 0;
   gXitk->x_error_handler = NULL;
   gXitk->modalw          = None;
+  gXitk->ignore_keys[0]  = XKeysymToKeycode(display, XK_Scroll_Lock);
+  gXitk->ignore_keys[1]  = XKeysymToKeycode(display, XK_Num_Lock);
+  gXitk->ignore_keys[2]  = XKeysymToKeycode(display, XK_Caps_Lock);
   gXitk->tips_timeout    = TIPS_TIMEOUT;
+  XGetInputFocus(display, &(gXitk->parent.window), &(gXitk->parent.focus));
 
   memset(&gXitk->keypress, 0, sizeof(gXitk->keypress));
 
@@ -2018,6 +2043,9 @@ void xitk_stop(void) {
   xitk_tips_deinit();
   xitk_cursors_deinit(gXitk->display);
   gXitk->running = 0;
+
+  if(gXitk->parent.window != None)
+    XSetInputFocus(gXitk->display, gXitk->parent.window, gXitk->parent.focus, CurrentTime);
 }
  
 char *xitk_get_system_font(void) {
